Update bytecode magic number for the 3.15 release candidate (#154881)

hugovk <[email protected]> Thu, 30 Jul 2026 15:48:29 -0400 (EDT)
Newsgroups gmane.comp.python.cvs
Message-ID <[email protected]>
https://github.com/python/cpython/commit/6489af6f5731874a48042fa445c4e94fca41ff30
commit: 6489af6f5731874a48042fa445c4e94fca41ff30
branch: main
author: Hugo van Kemenade <[email protected]>
committer: hugovk <[email protected]>
date: 2026-07-30T22:48:17+03:00
summary:

Update bytecode magic number for the 3.15 release candidate (#154881)

files:
M Lib/test/test_importlib/test_util.py

diff --git a/Lib/test/test_importlib/test_util.py b/Lib/test/test_importlib/test_util.py
index 8ec2dcd69e58b63..8a911c1b751a4b4 100644
--- a/Lib/test/test_importlib/test_util.py
+++ b/Lib/test/test_importlib/test_util.py
@@ -633,7 +633,7 @@ class MagicNumberTests(unittest.TestCase):
         'only applies to candidate or final python release levels'
     )
     def test_magic_number(self):
-        # Each python minor release should generally have a MAGIC_NUMBER
+        # Each Python feature release should generally have a MAGIC_NUMBER
         # that does not change once the release reaches candidate status.
 
         # Once a release reaches candidate status, the value of the constant
@@ -643,11 +643,11 @@ def test_magic_number(self):
 
         # In exceptional cases, it may be required to change the MAGIC_NUMBER
         # for a maintenance release. In this case the change should be
         # discussed in python-dev. If a change is required, community
         # stakeholders such as OS package maintainers must be notified
         # in advance. Such exceptional releases will then require an
         # adjustment to this test case.
-        EXPECTED_MAGIC_NUMBER = 3625
+        EXPECTED_MAGIC_NUMBER = 3666
         actual = int.from_bytes(importlib.util.MAGIC_NUMBER[:2], 'little')
 
         msg = (
@@ -659,7 +659,7 @@ def test_magic_number(self):
             "magic number in this test to the current MAGIC_NUMBER to "
             "continue with the release.\n\n"
             "Changing the MAGIC_NUMBER for a maintenance release "
-            "requires discussion in python-dev and notification of "
+            "requires discussion on Discourse and notification of "
             "community stakeholders."
         )
         self.assertEqual(EXPECTED_MAGIC_NUMBER, actual, msg)
@@ -643,11 +643,11 @@ def test_magic_number(self):
         # In exceptional cases, it may be required to change the MAGIC_NUMBER
         # for a maintenance release. In this case the change should be
-        # discussed in python-dev. If a change is required, community
+        # discussed in on Discourse. If a change is required, community
         # stakeholders such as OS package maintainers must be notified
         # in advance. Such exceptional releases will then require an

_______________________________________________
Python-checkins mailing list -- [email protected]
To unsubscribe send an email to [email protected]
https://mail.python.org/mailman3//lists/python-checkins.python.org
Member address: [email protected]